@@ -70,40 +70,24 @@ async def raise_exc_after_response(scope, receive, send):
     raise RuntimeError()
 
 
-async def empty_stream():
-    yield b""
-
-
 @pytest.mark.usefixtures("async_environment")
 async def test_asgi_transport():
     async with httpx.ASGITransport(app=hello_world) as transport:
-        status_code, headers, stream, ext = await transport.handle_async_request(
-            method=b"GET",
-            url=(b"http", b"www.example.org", 80, b"/"),
-            headers=[(b"Host", b"www.example.org")],
-            stream=empty_stream(),
-            extensions={},
-        )
-        body = b"".join([part async for part in stream])
-
-        assert status_code == 200
-        assert body == b"Hello, World!"
+        request = httpx.Request("GET", "http://www.example.com/")
+        response = await transport.handle_async_request(request)
+        await response.aread()
+        assert response.status_code == 200
+        assert response.content == b"Hello, World!"
 
 
 @pytest.mark.usefixtures("async_environment")
 async def test_asgi_transport_no_body():
     async with httpx.ASGITransport(app=echo_body) as transport:
-        status_code, headers, stream, ext = await transport.handle_async_request(
-            method=b"GET",
-            url=(b"http", b"www.example.org", 80, b"/"),
-            headers=[(b"Host", b"www.example.org")],
-            stream=empty_stream(),
-            extensions={},
-        )
-        body = b"".join([part async for part in stream])
-
-        assert status_code == 200
-        assert body == b""
+        request = httpx.Request("GET", "http://www.example.com/")
+        response = await transport.handle_async_request(request)
+        await response.aread()
+        assert response.status_code == 200
+        assert response.content == b""
 
 
 @pytest.mark.usefixtures("async_environment")
