@@ -18,6 +18,7 @@ def test_httpcore_all_exceptions_mapped() -> None:
         if isinstance(value, type)
         and issubclass(value, Exception)
         and value not in HTTPCORE_EXC_MAP
+        and value is not httpcore.ConnectionNotAvailable
     ]
 
     if not_mapped:  # pragma: nocover
@@ -39,33 +40,21 @@ def test_httpcore_exception_mapping(server) -> None:
         def close(self):
             pass
 
-    class CloseFailedStream:
-        def __iter__(self):
-            yield b""
-
-        def close(self):
-            raise httpcore.CloseError()
-
     with mock.patch(
-        "httpcore.SyncConnectionPool.handle_request", side_effect=connect_failed
+        "httpcore.ConnectionPool.handle_request", side_effect=connect_failed
     ):
         with pytest.raises(httpx.ConnectError):
             httpx.get(server.url)
 
     with mock.patch(
-        "httpcore.SyncConnectionPool.handle_request",
-        return_value=(200, [], TimeoutStream(), {}),
+        "httpcore.ConnectionPool.handle_request",
+        return_value=httpcore.Response(
+            200, headers=[], content=TimeoutStream(), extensions={}
+        ),
     ):
         with pytest.raises(httpx.ReadTimeout):
             httpx.get(server.url)
 
-    with mock.patch(
-        "httpcore.SyncConnectionPool.handle_request",
-        return_value=(200, [], CloseFailedStream(), {}),
-    ):
-        with pytest.raises(httpx.CloseError):
-            httpx.get(server.url)
-
 
 def test_httpx_exceptions_exposed() -> None:
     """
