@@ -1,5 +1,3 @@
-import pytest
-
 import httpx
 
 
@@ -26,14 +24,3 @@ def test_reason_phrase_for_status_code():
 
 def test_reason_phrase_for_unknown_status_code():
     assert httpx.codes.get_reason_phrase(499) == ""
-
-
-def test_deprecated_status_code_class():
-    with pytest.warns(DeprecationWarning):
-        assert httpx.StatusCode.NOT_FOUND == 404
-
-    with pytest.warns(DeprecationWarning):
-        assert httpx.StatusCode(404) == 404
-
-    with pytest.warns(DeprecationWarning):
-        assert httpx.StatusCode["NOT_FOUND"] == 404
